.. module:: bana.OpenMaya.MVector

.. _openmaya_mvector:

OpenMaya.MVector
================

.. autosummary::
   :nosignatures:

   ~MVector.__str__
   ~MVector.bnGet
   ~MVector.bnRotateBy


----

.. automethod:: MVector.__str__

----

.. automethod:: MVector.bnGet

----

.. automethod:: MVector.bnRotateBy
